% ASCOS_cruise_map_with_inset
%
% ** Requires the free m_map toolbox **
%
% expects the following to be loaded in workspace:
%   - svalbardpatch and greenland75patch cell arrays 
%   - shippos structure

figure;
hold on
wysiwyg
m_proj('stereographic'); % set map projecttion


% plot optional drift box
x = [-12:0.1:0];
y = [87.1:0.05:87.55];
m_plot(x,min(y)*ones(size(x)),'-','color',[1 1 1]*0.7);
m_plot(x,max(y)*ones(size(x)),'-','color',[1 1 1]*0.7);
m_plot(min(x)*ones(size(y)),y,'-','color',[1 1 1]*0.7);
m_plot(max(x)*ones(size(y)),y,'-','color',[1 1 1]*0.7);


% plot grid lines
latgridvalues = [75 80 85];
x = [-180:0.2:180];
for n = 1:length(latgridvalues)
  hlatgrid(n) = m_plot(x,ones(size(x))*latgridvalues(n),'k:');
end
longridvalues=[0:30:330];
y=[90:-1:min(latgridvalues)];
for n = 1:length(longridvalues)
  hlongrid(n) = m_plot(ones(size(y))*longridvalues(n),y,'k:');
end


% plot ice edge - defined here as 50% concentration contour (transition is 
%                 quite sharp, so 'edge' doesn't move much with frac <50%
m_contour(icelon,icelat,icefrac,[1 1]*50,'b--')

% plot the ship track
iidrift = find(shippos.time>datenum(2008,8,12,12,0,0) & ...
          shippos.time<datenum(2008,9,2,0,0,0));
m_plot(shippos.lon,shippos.lat,'color',[1 0.6 0.6],'linewidth',1.5);
m_plot(shippos.lon(iidrift),shippos.lat(iidrift),'color','r','linewidth',1.5);

for n = 1:length(svalbardpatch)
  m_patch(svalbardpatch{n}(:,1),svalbardpatch{n}(:,2),[1 1 1]*0.8,...
          'edgecolor','none');
end
for n = 1:length(greenland75patch)
  m_patch(greenland75patch{n}(:,1),greenland75patch{n}(:,2),[1 1 1]*0.8,...
         'edgecolor','none');
end

% fix the axis box
set(gca,'box','on')
set(gca,'dataaspectRatio',[1 1 1])
set(gca,'xlim',[-0.1 0.1]+0.03,'ylim',[0.3 0.5]); % << adjust 

set(gca,'xtick',[],'ytick',[]); % comment this out to see x- and y-scales when 
                                % fine-tuning limits

%--------------------------------------------------------------------------
% drop blank axes over top to force box over patches
pp = get(gca,'position');
xlim=get(gca,'xlim');
ylim=get(gca,'ylim');
ax2 = axes('position',pp);
set(ax2,'color','none','xlim',xlim,'ylim',ylim,'dataaspectratio',[1 1 1],...
        'box','on','xtick',[],'ytick',[],'linewidth',2);
      
% add text labels 
t1(1) = m_text(-15,85,'85');
t1(2) = m_text(-15,80,'80');
set(t1,'horizontalalignment','center','rotation',-15,'fontsize',12,...
      'backgroundcolor','w','margin',0.1)

t2(1) = m_text(0,78,'0');
t2(2) = m_text(30,78,'30');
set(t2(1),'horizontalalignment','center','rotation',0,'fontsize',12,...
      'backgroundcolor','w','margin',0.1)
set(t2(2),'horizontalalignment','center','rotation',30,'fontsize',12,...
      'backgroundcolor','w','margin',0.1)

m_text(12,79,'Svalbard','fontsize',12)

%--------------------------------------------------------------------------
% add inset of ice drift period
axes('position',[0.51 0.54 0.295 0.4]);
m_proj('mercator','longitude',[-12 0],'latitude',[87.1 87.55]);

m_plot(shippos.lon(iidrift),shippos.lat(iidrift),'r','linewidth',2);
hold on
m_plot(shippos.lon(iidrift(1)),shippos.lat(iidrift(1)),'ro');
hold on
set(gca,'xtick',[],'ytick',[]) % comment out to view axis native units
set(gca,'dataaspectratio',[1 1 1])

% plot grid lines
latgridvalues = [87.1:0.1:87.5];
x = [-12:0];
for n = 1:length(latgridvalues)
  m_plot(x,ones(size(x))*latgridvalues(n),':','color',[1 1 1]*0.6);
  ytext = num2str(latgridvalues(n));
  m_text(-13.34,latgridvalues(n),ytext,'fontsize',10,'fontweight','bold');
end

longridvalues=[-12:2:0];
y=[87.1:0.01:87.6];
for n = 1:length(longridvalues)
  m_plot(ones(size(y))*longridvalues(n),y,':','color',[1 1 1]*0.6);
  if longridvalues(n)<0
    m_text(longridvalues(n),87.075,num2str(longridvalues(n)),...
       'horizontalalignment','center','fontsize',10,'fontweight','bold');
  else
    m_text(longridvalues(n),87.075,num2str(longridvalues(n)),...
       'horizontalalignment','right','fontsize',10,'fontweight','bold');
  end
end
set(gca,'xlim',[-0.1 0.1],'ylim',[3.677 3.84],'linewidth',1,'box','on')
